@@ -9,16 +9,18 @@ use Test::More;
 
 use Yahoo::Marketing::Preferences;
 
-sub test_can_create_preferences_and_set_all_fields : Test(3) {
+sub test_can_create_preferences_and_set_all_fields : Test(4) {
 
     my $preferences = Yahoo::Marketing::Preferences->new
                                                    ->includeCampaignBudget( 'include campaign budget' )
+                                                   ->includeKeywordUrl( 'include keyword url' )
                                                    ->includeNegativeKeywords( 'include negative keywords' )
                    ;
 
     ok( $preferences );
 
     is( $preferences->includeCampaignBudget, 'include campaign budget', 'can get include campaign budget' );
+    is( $preferences->includeKeywordUrl, 'include keyword url', 'can get include keyword url' );
     is( $preferences->includeNegativeKeywords, 'include negative keywords', 'can get include negative keywords' );
 
 };
